# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class XlsxSpreadsheetCell(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'path': 'str',
        'text_value': 'str',
        'cell_identifier': 'str',
        'style_index': 'int',
        'formula': 'str'
    }

    attribute_map = {
        'path': 'Path',
        'text_value': 'TextValue',
        'cell_identifier': 'CellIdentifier',
        'style_index': 'StyleIndex',
        'formula': 'Formula'
    }

    def __init__(self, path=None, text_value=None, cell_identifier=None, style_index=None, formula=None):  # noqa: E501
        """XlsxSpreadsheetCell - a model defined in Swagger"""  # noqa: E501

        self._path = None
        self._text_value = None
        self._cell_identifier = None
        self._style_index = None
        self._formula = None
        self.discriminator = None

        if path is not None:
            self.path = path
        if text_value is not None:
            self.text_value = text_value
        if cell_identifier is not None:
            self.cell_identifier = cell_identifier
        if style_index is not None:
            self.style_index = style_index
        if formula is not None:
            self.formula = formula

    @property
    def path(self):
        """Gets the path of this XlsxSpreadsheetCell.  # noqa: E501

        The Path of the location of this object; leave blank for new rows  # noqa: E501

        :return: The path of this XlsxSpreadsheetCell.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this XlsxSpreadsheetCell.

        The Path of the location of this object; leave blank for new rows  # noqa: E501

        :param path: The path of this XlsxSpreadsheetCell.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def text_value(self):
        """Gets the text_value of this XlsxSpreadsheetCell.  # noqa: E501

        Text value of the cell  # noqa: E501

        :return: The text_value of this XlsxSpreadsheetCell.  # noqa: E501
        :rtype: str
        """
        return self._text_value

    @text_value.setter
    def text_value(self, text_value):
        """Sets the text_value of this XlsxSpreadsheetCell.

        Text value of the cell  # noqa: E501

        :param text_value: The text_value of this XlsxSpreadsheetCell.  # noqa: E501
        :type: str
        """

        self._text_value = text_value

    @property
    def cell_identifier(self):
        """Gets the cell_identifier of this XlsxSpreadsheetCell.  # noqa: E501

        Cell reference of the cell, e.g. A1, Z22, etc.  # noqa: E501

        :return: The cell_identifier of this XlsxSpreadsheetCell.  # noqa: E501
        :rtype: str
        """
        return self._cell_identifier

    @cell_identifier.setter
    def cell_identifier(self, cell_identifier):
        """Sets the cell_identifier of this XlsxSpreadsheetCell.

        Cell reference of the cell, e.g. A1, Z22, etc.  # noqa: E501

        :param cell_identifier: The cell_identifier of this XlsxSpreadsheetCell.  # noqa: E501
        :type: str
        """

        self._cell_identifier = cell_identifier

    @property
    def style_index(self):
        """Gets the style_index of this XlsxSpreadsheetCell.  # noqa: E501

        Identifier for the style to apply to this style  # noqa: E501

        :return: The style_index of this XlsxSpreadsheetCell.  # noqa: E501
        :rtype: int
        """
        return self._style_index

    @style_index.setter
    def style_index(self, style_index):
        """Sets the style_index of this XlsxSpreadsheetCell.

        Identifier for the style to apply to this style  # noqa: E501

        :param style_index: The style_index of this XlsxSpreadsheetCell.  # noqa: E501
        :type: int
        """

        self._style_index = style_index

    @property
    def formula(self):
        """Gets the formula of this XlsxSpreadsheetCell.  # noqa: E501


        :return: The formula of this XlsxSpreadsheetCell.  # noqa: E501
        :rtype: str
        """
        return self._formula

    @formula.setter
    def formula(self, formula):
        """Sets the formula of this XlsxSpreadsheetCell.


        :param formula: The formula of this XlsxSpreadsheetCell.  # noqa: E501
        :type: str
        """

        self._formula = formula

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(XlsxSpreadsheetCell, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, XlsxSpreadsheetCell):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from cloudmersive_convert_api_client.models.add_pdf_annotation_request import AddPdfAnnotationRequest
from cloudmersive_convert_api_client.models.alternate_file_format_candidate import AlternateFileFormatCandidate
from cloudmersive_convert_api_client.models.append_xlsx_row_request import AppendXlsxRowRequest
from cloudmersive_convert_api_client.models.append_xlsx_row_response import AppendXlsxRowResponse
from cloudmersive_convert_api_client.models.autodetect_document_validation_result import AutodetectDocumentValidationResult
from cloudmersive_convert_api_client.models.autodetect_get_info_result import AutodetectGetInfoResult
from cloudmersive_convert_api_client.models.autodetect_to_jpg_result import AutodetectToJpgResult
from cloudmersive_convert_api_client.models.autodetect_to_png_result import AutodetectToPngResult
from cloudmersive_convert_api_client.models.autodetect_to_thumbnails_result import AutodetectToThumbnailsResult
from cloudmersive_convert_api_client.models.base64_decode_request import Base64DecodeRequest
from cloudmersive_convert_api_client.models.base64_decode_response import Base64DecodeResponse
from cloudmersive_convert_api_client.models.base64_detect_request import Base64DetectRequest
from cloudmersive_convert_api_client.models.base64_detect_response import Base64DetectResponse
from cloudmersive_convert_api_client.models.base64_encode_request import Base64EncodeRequest
from cloudmersive_convert_api_client.models.base64_encode_response import Base64EncodeResponse
from cloudmersive_convert_api_client.models.change_line_ending_response import ChangeLineEndingResponse
from cloudmersive_convert_api_client.models.clear_xlsx_cell_request import ClearXlsxCellRequest
from cloudmersive_convert_api_client.models.clear_xlsx_cell_response import ClearXlsxCellResponse
from cloudmersive_convert_api_client.models.clear_xlsx_row_request import ClearXlsxRowRequest
from cloudmersive_convert_api_client.models.clear_xlsx_row_response import ClearXlsxRowResponse
from cloudmersive_convert_api_client.models.converted_jpg_page import ConvertedJpgPage
from cloudmersive_convert_api_client.models.converted_png_page import ConvertedPngPage
from cloudmersive_convert_api_client.models.create_blank_docx_request import CreateBlankDocxRequest
from cloudmersive_convert_api_client.models.create_blank_docx_response import CreateBlankDocxResponse
from cloudmersive_convert_api_client.models.create_blank_spreadsheet_request import CreateBlankSpreadsheetRequest
from cloudmersive_convert_api_client.models.create_blank_spreadsheet_response import CreateBlankSpreadsheetResponse
from cloudmersive_convert_api_client.models.create_spreadsheet_from_data_request import CreateSpreadsheetFromDataRequest
from cloudmersive_convert_api_client.models.create_spreadsheet_from_data_response import CreateSpreadsheetFromDataResponse
from cloudmersive_convert_api_client.models.create_zip_archive_request import CreateZipArchiveRequest
from cloudmersive_convert_api_client.models.csv_collection import CsvCollection
from cloudmersive_convert_api_client.models.csv_file_result import CsvFileResult
from cloudmersive_convert_api_client.models.delete_docx_table_row_range_request import DeleteDocxTableRowRangeRequest
from cloudmersive_convert_api_client.models.delete_docx_table_row_range_response import DeleteDocxTableRowRangeResponse
from cloudmersive_convert_api_client.models.delete_docx_table_row_request import DeleteDocxTableRowRequest
from cloudmersive_convert_api_client.models.delete_docx_table_row_response import DeleteDocxTableRowResponse
from cloudmersive_convert_api_client.models.detect_line_endings_response import DetectLineEndingsResponse
from cloudmersive_convert_api_client.models.disable_shared_workbook_request import DisableSharedWorkbookRequest
from cloudmersive_convert_api_client.models.disable_shared_workbook_response import DisableSharedWorkbookResponse
from cloudmersive_convert_api_client.models.document_validation_error import DocumentValidationError
from cloudmersive_convert_api_client.models.document_validation_result import DocumentValidationResult
from cloudmersive_convert_api_client.models.docx_body import DocxBody
from cloudmersive_convert_api_client.models.docx_cell_style import DocxCellStyle
from cloudmersive_convert_api_client.models.docx_comment import DocxComment
from cloudmersive_convert_api_client.models.docx_footer import DocxFooter
from cloudmersive_convert_api_client.models.docx_header import DocxHeader
from cloudmersive_convert_api_client.models.docx_image import DocxImage
from cloudmersive_convert_api_client.models.docx_insert_comment_on_paragraph_request import DocxInsertCommentOnParagraphRequest
from cloudmersive_convert_api_client.models.docx_insert_image_request import DocxInsertImageRequest
from cloudmersive_convert_api_client.models.docx_insert_image_response import DocxInsertImageResponse
from cloudmersive_convert_api_client.models.docx_page import DocxPage
from cloudmersive_convert_api_client.models.docx_paragraph import DocxParagraph
from cloudmersive_convert_api_client.models.docx_remove_object_request import DocxRemoveObjectRequest
from cloudmersive_convert_api_client.models.docx_remove_object_response import DocxRemoveObjectResponse
from cloudmersive_convert_api_client.models.docx_run import DocxRun
from cloudmersive_convert_api_client.models.docx_section import DocxSection
from cloudmersive_convert_api_client.models.docx_set_footer_add_page_number_request import DocxSetFooterAddPageNumberRequest
from cloudmersive_convert_api_client.models.docx_set_footer_request import DocxSetFooterRequest
from cloudmersive_convert_api_client.models.docx_set_footer_response import DocxSetFooterResponse
from cloudmersive_convert_api_client.models.docx_set_header_request import DocxSetHeaderRequest
from cloudmersive_convert_api_client.models.docx_set_header_response import DocxSetHeaderResponse
from cloudmersive_convert_api_client.models.docx_style import DocxStyle
from cloudmersive_convert_api_client.models.docx_table import DocxTable
from cloudmersive_convert_api_client.models.docx_table_cell import DocxTableCell
from cloudmersive_convert_api_client.models.docx_table_row import DocxTableRow
from cloudmersive_convert_api_client.models.docx_template_application_request import DocxTemplateApplicationRequest
from cloudmersive_convert_api_client.models.docx_template_operation import DocxTemplateOperation
from cloudmersive_convert_api_client.models.docx_text import DocxText
from cloudmersive_convert_api_client.models.docx_to_jpg_result import DocxToJpgResult
from cloudmersive_convert_api_client.models.docx_to_png_result import DocxToPngResult
from cloudmersive_convert_api_client.models.docx_top_level_comment import DocxTopLevelComment
from cloudmersive_convert_api_client.models.eml_attachment import EmlAttachment
from cloudmersive_convert_api_client.models.eml_to_html_result import EmlToHtmlResult
from cloudmersive_convert_api_client.models.eml_to_jpg_result import EmlToJpgResult
from cloudmersive_convert_api_client.models.eml_to_png_result import EmlToPngResult
from cloudmersive_convert_api_client.models.enable_shared_workbook_request import EnableSharedWorkbookRequest
from cloudmersive_convert_api_client.models.enable_shared_workbook_response import EnableSharedWorkbookResponse
from cloudmersive_convert_api_client.models.exif_value import ExifValue
from cloudmersive_convert_api_client.models.find_docx_paragraph_request import FindDocxParagraphRequest
from cloudmersive_convert_api_client.models.find_docx_paragraph_response import FindDocxParagraphResponse
from cloudmersive_convert_api_client.models.find_regex_match import FindRegexMatch
from cloudmersive_convert_api_client.models.find_string_match import FindStringMatch
from cloudmersive_convert_api_client.models.find_string_regex_request import FindStringRegexRequest
from cloudmersive_convert_api_client.models.find_string_regex_response import FindStringRegexResponse
from cloudmersive_convert_api_client.models.find_string_simple_request import FindStringSimpleRequest
from cloudmersive_convert_api_client.models.find_string_simple_response import FindStringSimpleResponse
from cloudmersive_convert_api_client.models.finish_editing_request import FinishEditingRequest
from cloudmersive_convert_api_client.models.get_docx_body_request import GetDocxBodyRequest
from cloudmersive_convert_api_client.models.get_docx_body_response import GetDocxBodyResponse
from cloudmersive_convert_api_client.models.get_docx_comments_hierarchical_response import GetDocxCommentsHierarchicalResponse
from cloudmersive_convert_api_client.models.get_docx_comments_response import GetDocxCommentsResponse
from cloudmersive_convert_api_client.models.get_docx_get_comments_hierarchical_request import GetDocxGetCommentsHierarchicalRequest
from cloudmersive_convert_api_client.models.get_docx_get_comments_request import GetDocxGetCommentsRequest
from cloudmersive_convert_api_client.models.get_docx_headers_and_footers_request import GetDocxHeadersAndFootersRequest
from cloudmersive_convert_api_client.models.get_docx_headers_and_footers_response import GetDocxHeadersAndFootersResponse
from cloudmersive_convert_api_client.models.get_docx_images_request import GetDocxImagesRequest
from cloudmersive_convert_api_client.models.get_docx_images_response import GetDocxImagesResponse
from cloudmersive_convert_api_client.models.get_docx_pages_request import GetDocxPagesRequest
from cloudmersive_convert_api_client.models.get_docx_pages_response import GetDocxPagesResponse
from cloudmersive_convert_api_client.models.get_docx_sections_request import GetDocxSectionsRequest
from cloudmersive_convert_api_client.models.get_docx_sections_response import GetDocxSectionsResponse
from cloudmersive_convert_api_client.models.get_docx_styles_request import GetDocxStylesRequest
from cloudmersive_convert_api_client.models.get_docx_styles_response import GetDocxStylesResponse
from cloudmersive_convert_api_client.models.get_docx_table_by_index_request import GetDocxTableByIndexRequest
from cloudmersive_convert_api_client.models.get_docx_table_by_index_response import GetDocxTableByIndexResponse
from cloudmersive_convert_api_client.models.get_docx_table_row_request import GetDocxTableRowRequest
from cloudmersive_convert_api_client.models.get_docx_table_row_response import GetDocxTableRowResponse
from cloudmersive_convert_api_client.models.get_docx_tables_request import GetDocxTablesRequest
from cloudmersive_convert_api_client.models.get_docx_tables_response import GetDocxTablesResponse
from cloudmersive_convert_api_client.models.get_file_type_icon_result import GetFileTypeIconResult
from cloudmersive_convert_api_client.models.get_image_info_result import GetImageInfoResult
from cloudmersive_convert_api_client.models.get_pdf_annotations_result import GetPdfAnnotationsResult
from cloudmersive_convert_api_client.models.get_xlsx_cell_by_identifier_request import GetXlsxCellByIdentifierRequest
from cloudmersive_convert_api_client.models.get_xlsx_cell_by_identifier_response import GetXlsxCellByIdentifierResponse
from cloudmersive_convert_api_client.models.get_xlsx_cell_request import GetXlsxCellRequest
from cloudmersive_convert_api_client.models.get_xlsx_cell_response import GetXlsxCellResponse
from cloudmersive_convert_api_client.models.get_xlsx_columns_request import GetXlsxColumnsRequest
from cloudmersive_convert_api_client.models.get_xlsx_columns_response import GetXlsxColumnsResponse
from cloudmersive_convert_api_client.models.get_xlsx_images_request import GetXlsxImagesRequest
from cloudmersive_convert_api_client.models.get_xlsx_images_response import GetXlsxImagesResponse
from cloudmersive_convert_api_client.models.get_xlsx_rows_and_cells_request import GetXlsxRowsAndCellsRequest
from cloudmersive_convert_api_client.models.get_xlsx_rows_and_cells_response import GetXlsxRowsAndCellsResponse
from cloudmersive_convert_api_client.models.get_xlsx_specific_row_request import GetXlsxSpecificRowRequest
from cloudmersive_convert_api_client.models.get_xlsx_specific_row_response import GetXlsxSpecificRowResponse
from cloudmersive_convert_api_client.models.get_xlsx_styles_request import GetXlsxStylesRequest
from cloudmersive_convert_api_client.models.get_xlsx_styles_response import GetXlsxStylesResponse
from cloudmersive_convert_api_client.models.get_xlsx_worksheets_request import GetXlsxWorksheetsRequest
from cloudmersive_convert_api_client.models.get_xlsx_worksheets_response import GetXlsxWorksheetsResponse
from cloudmersive_convert_api_client.models.html_md_result import HtmlMdResult
from cloudmersive_convert_api_client.models.html_template_application_request import HtmlTemplateApplicationRequest
from cloudmersive_convert_api_client.models.html_template_application_response import HtmlTemplateApplicationResponse
from cloudmersive_convert_api_client.models.html_template_operation import HtmlTemplateOperation
from cloudmersive_convert_api_client.models.html_to_office_request import HtmlToOfficeRequest
from cloudmersive_convert_api_client.models.html_to_pdf_request import HtmlToPdfRequest
from cloudmersive_convert_api_client.models.html_to_png_request import HtmlToPngRequest
from cloudmersive_convert_api_client.models.html_to_text_request import HtmlToTextRequest
from cloudmersive_convert_api_client.models.html_to_text_response import HtmlToTextResponse
from cloudmersive_convert_api_client.models.insert_docx_comment_on_paragraph_response import InsertDocxCommentOnParagraphResponse
from cloudmersive_convert_api_client.models.insert_docx_insert_paragraph_request import InsertDocxInsertParagraphRequest
from cloudmersive_convert_api_client.models.insert_docx_insert_paragraph_response import InsertDocxInsertParagraphResponse
from cloudmersive_convert_api_client.models.insert_docx_table_row_request import InsertDocxTableRowRequest
from cloudmersive_convert_api_client.models.insert_docx_table_row_response import InsertDocxTableRowResponse
from cloudmersive_convert_api_client.models.insert_docx_tables_request import InsertDocxTablesRequest
from cloudmersive_convert_api_client.models.insert_docx_tables_response import InsertDocxTablesResponse
from cloudmersive_convert_api_client.models.insert_xlsx_worksheet_request import InsertXlsxWorksheetRequest
from cloudmersive_convert_api_client.models.insert_xlsx_worksheet_response import InsertXlsxWorksheetResponse
from cloudmersive_convert_api_client.models.keynote_to_jpg_result import KeynoteToJpgResult
from cloudmersive_convert_api_client.models.keynote_to_png_result import KeynoteToPngResult
from cloudmersive_convert_api_client.models.msg_attachment import MsgAttachment
from cloudmersive_convert_api_client.models.msg_to_html_result import MsgToHtmlResult
from cloudmersive_convert_api_client.models.msg_to_jpg_result import MsgToJpgResult
from cloudmersive_convert_api_client.models.msg_to_png_result import MsgToPngResult
from cloudmersive_convert_api_client.models.multipage_image_format_conversion_result import MultipageImageFormatConversionResult
from cloudmersive_convert_api_client.models.odp_to_jpg_result import OdpToJpgResult
from cloudmersive_convert_api_client.models.odp_to_png_result import OdpToPngResult
from cloudmersive_convert_api_client.models.ods_to_jpg_result import OdsToJpgResult
from cloudmersive_convert_api_client.models.ods_to_png_result import OdsToPngResult
from cloudmersive_convert_api_client.models.odt_to_jpg_result import OdtToJpgResult
from cloudmersive_convert_api_client.models.odt_to_png_result import OdtToPngResult
from cloudmersive_convert_api_client.models.page_conversion_result import PageConversionResult
from cloudmersive_convert_api_client.models.pdf_annotation import PdfAnnotation
from cloudmersive_convert_api_client.models.pdf_document import PdfDocument
from cloudmersive_convert_api_client.models.pdf_form_field import PdfFormField
from cloudmersive_convert_api_client.models.pdf_form_fields import PdfFormFields
from cloudmersive_convert_api_client.models.pdf_metadata import PdfMetadata
from cloudmersive_convert_api_client.models.pdf_page_text import PdfPageText
from cloudmersive_convert_api_client.models.pdf_text_by_page_result import PdfTextByPageResult
from cloudmersive_convert_api_client.models.pdf_to_png_result import PdfToPngResult
from cloudmersive_convert_api_client.models.pptx_to_png_result import PptxToPngResult
from cloudmersive_convert_api_client.models.presentation_result import PresentationResult
from cloudmersive_convert_api_client.models.remove_docx_headers_and_footers_request import RemoveDocxHeadersAndFootersRequest
from cloudmersive_convert_api_client.models.remove_docx_headers_and_footers_response import RemoveDocxHeadersAndFootersResponse
from cloudmersive_convert_api_client.models.remove_docx_pages_request import RemoveDocxPagesRequest
from cloudmersive_convert_api_client.models.remove_html_from_text_request import RemoveHtmlFromTextRequest
from cloudmersive_convert_api_client.models.remove_html_from_text_response import RemoveHtmlFromTextResponse
from cloudmersive_convert_api_client.models.remove_pptx_slides_request import RemovePptxSlidesRequest
from cloudmersive_convert_api_client.models.remove_whitespace_from_text_request import RemoveWhitespaceFromTextRequest
from cloudmersive_convert_api_client.models.remove_whitespace_from_text_response import RemoveWhitespaceFromTextResponse
from cloudmersive_convert_api_client.models.remove_xlsx_worksheet_request import RemoveXlsxWorksheetRequest
from cloudmersive_convert_api_client.models.rename_xlsx_worksheet_request import RenameXlsxWorksheetRequest
from cloudmersive_convert_api_client.models.rename_xlsx_worksheet_response import RenameXlsxWorksheetResponse
from cloudmersive_convert_api_client.models.replace_docx_paragraph_request import ReplaceDocxParagraphRequest
from cloudmersive_convert_api_client.models.replace_docx_paragraph_response import ReplaceDocxParagraphResponse
from cloudmersive_convert_api_client.models.replace_string_regex_request import ReplaceStringRegexRequest
from cloudmersive_convert_api_client.models.replace_string_regex_response import ReplaceStringRegexResponse
from cloudmersive_convert_api_client.models.replace_string_request import ReplaceStringRequest
from cloudmersive_convert_api_client.models.replace_string_simple_request import ReplaceStringSimpleRequest
from cloudmersive_convert_api_client.models.replace_string_simple_response import ReplaceStringSimpleResponse
from cloudmersive_convert_api_client.models.rtf_to_jpg_result import RtfToJpgResult
from cloudmersive_convert_api_client.models.rtf_to_png_result import RtfToPngResult
from cloudmersive_convert_api_client.models.screenshot_request import ScreenshotRequest
from cloudmersive_convert_api_client.models.set_form_field_value import SetFormFieldValue
from cloudmersive_convert_api_client.models.set_pdf_form_fields_request import SetPdfFormFieldsRequest
from cloudmersive_convert_api_client.models.set_pdf_metadata_request import SetPdfMetadataRequest
from cloudmersive_convert_api_client.models.set_xlsx_cell_by_identifier_request import SetXlsxCellByIdentifierRequest
from cloudmersive_convert_api_client.models.set_xlsx_cell_by_identifier_response import SetXlsxCellByIdentifierResponse
from cloudmersive_convert_api_client.models.set_xlsx_cell_request import SetXlsxCellRequest
from cloudmersive_convert_api_client.models.set_xlsx_cell_response import SetXlsxCellResponse
from cloudmersive_convert_api_client.models.split_document_result import SplitDocumentResult
from cloudmersive_convert_api_client.models.split_docx_document_result import SplitDocxDocumentResult
from cloudmersive_convert_api_client.models.split_pdf_result import SplitPdfResult
from cloudmersive_convert_api_client.models.split_pptx_presentation_result import SplitPptxPresentationResult
from cloudmersive_convert_api_client.models.split_text_document_by_lines_result import SplitTextDocumentByLinesResult
from cloudmersive_convert_api_client.models.split_text_document_by_string_result import SplitTextDocumentByStringResult
from cloudmersive_convert_api_client.models.split_xlsx_worksheet_result import SplitXlsxWorksheetResult
from cloudmersive_convert_api_client.models.text_conversion_result import TextConversionResult
from cloudmersive_convert_api_client.models.text_document_element import TextDocumentElement
from cloudmersive_convert_api_client.models.text_document_line import TextDocumentLine
from cloudmersive_convert_api_client.models.text_encoding_detect_response import TextEncodingDetectResponse
from cloudmersive_convert_api_client.models.thumbnail import Thumbnail
from cloudmersive_convert_api_client.models.update_docx_table_cell_request import UpdateDocxTableCellRequest
from cloudmersive_convert_api_client.models.update_docx_table_cell_response import UpdateDocxTableCellResponse
from cloudmersive_convert_api_client.models.update_docx_table_row_request import UpdateDocxTableRowRequest
from cloudmersive_convert_api_client.models.update_docx_table_row_response import UpdateDocxTableRowResponse
from cloudmersive_convert_api_client.models.url_to_pdf_request import UrlToPdfRequest
from cloudmersive_convert_api_client.models.url_to_text_request import UrlToTextRequest
from cloudmersive_convert_api_client.models.url_to_text_response import UrlToTextResponse
from cloudmersive_convert_api_client.models.viewer_response import ViewerResponse
from cloudmersive_convert_api_client.models.worksheet_result import WorksheetResult
from cloudmersive_convert_api_client.models.xlsx_image import XlsxImage
from cloudmersive_convert_api_client.models.xlsx_spreadsheet_cell import XlsxSpreadsheetCell
from cloudmersive_convert_api_client.models.xlsx_spreadsheet_column import XlsxSpreadsheetColumn
from cloudmersive_convert_api_client.models.xlsx_spreadsheet_row import XlsxSpreadsheetRow
from cloudmersive_convert_api_client.models.xlsx_to_png_result import XlsxToPngResult
from cloudmersive_convert_api_client.models.xlsx_worksheet import XlsxWorksheet
from cloudmersive_convert_api_client.models.xml_add_attribute_with_x_path_result import XmlAddAttributeWithXPathResult
from cloudmersive_convert_api_client.models.xml_add_child_with_x_path_result import XmlAddChildWithXPathResult
from cloudmersive_convert_api_client.models.xml_filter_with_x_path_result import XmlFilterWithXPathResult
from cloudmersive_convert_api_client.models.xml_query_with_x_query_multi_result import XmlQueryWithXQueryMultiResult
from cloudmersive_convert_api_client.models.xml_query_with_x_query_result import XmlQueryWithXQueryResult
from cloudmersive_convert_api_client.models.xml_remove_all_children_with_x_path_result import XmlRemoveAllChildrenWithXPathResult
from cloudmersive_convert_api_client.models.xml_remove_with_x_path_result import XmlRemoveWithXPathResult
from cloudmersive_convert_api_client.models.xml_replace_with_x_path_result import XmlReplaceWithXPathResult
from cloudmersive_convert_api_client.models.xml_set_value_with_x_path_result import XmlSetValueWithXPathResult
from cloudmersive_convert_api_client.models.zip_directory import ZipDirectory
from cloudmersive_convert_api_client.models.zip_encryption_advanced_request import ZipEncryptionAdvancedRequest
from cloudmersive_convert_api_client.models.zip_extract_response import ZipExtractResponse
from cloudmersive_convert_api_client.models.zip_file import ZipFile



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ExifValue(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tag': 'str',
        'data_type': 'str',
        'data_value': 'str'
    }

    attribute_map = {
        'tag': 'Tag',
        'data_type': 'DataType',
        'data_value': 'DataValue'
    }

    def __init__(self, tag=None, data_type=None, data_value=None):  # noqa: E501
        """ExifValue - a model defined in Swagger"""  # noqa: E501

        self._tag = None
        self._data_type = None
        self._data_value = None
        self.discriminator = None

        if tag is not None:
            self.tag = tag
        if data_type is not None:
            self.data_type = data_type
        if data_value is not None:
            self.data_value = data_value

    @property
    def tag(self):
        """Gets the tag of this ExifValue.  # noqa: E501

        Tag name for the EXIF value  # noqa: E501

        :return: The tag of this ExifValue.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this ExifValue.

        Tag name for the EXIF value  # noqa: E501

        :param tag: The tag of this ExifValue.  # noqa: E501
        :type: str
        """

        self._tag = tag

    @property
    def data_type(self):
        """Gets the data_type of this ExifValue.  # noqa: E501

        Date type of the EXIF value  # noqa: E501

        :return: The data_type of this ExifValue.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this ExifValue.

        Date type of the EXIF value  # noqa: E501

        :param data_type: The data_type of this ExifValue.  # noqa: E501
        :type: str
        """

        self._data_type = data_type

    @property
    def data_value(self):
        """Gets the data_value of this ExifValue.  # noqa: E501

        Value, formatted as a string of the EXIF value  # noqa: E501

        :return: The data_value of this ExifValue.  # noqa: E501
        :rtype: str
        """
        return self._data_value

    @data_value.setter
    def data_value(self, data_value):
        """Sets the data_value of this ExifValue.

        Value, formatted as a string of the EXIF value  # noqa: E501

        :param data_value: The data_value of this ExifValue.  # noqa: E501
        :type: str
        """

        self._data_value = data_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExifValue, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExifValue):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_convert_api_client
from cloudmersive_convert_api_client.api.convert_document_api import ConvertDocumentApi  # noqa: E501
from cloudmersive_convert_api_client.rest import ApiException


class TestConvertDocumentApi(unittest.TestCase):
    """ConvertDocumentApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_convert_api_client.api.convert_document_api.ConvertDocumentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_convert_document_autodetect_to_pdf(self):
        """Test case for convert_document_autodetect_to_pdf

        Convert Document to PDF  # noqa: E501
        """
        pass

    def test_convert_document_docx_to_pdf(self):
        """Test case for convert_document_docx_to_pdf

        Word DOCX to PDF  # noqa: E501
        """
        pass

    def test_convert_document_pptx_to_pdf(self):
        """Test case for convert_document_pptx_to_pdf

        PowerPoint PPTX to PDF  # noqa: E501
        """
        pass

    def test_convert_document_xlsx_to_csv(self):
        """Test case for convert_document_xlsx_to_csv

        Excel XLSX to CSV  # noqa: E501
        """
        pass

    def test_convert_document_xlsx_to_pdf(self):
        """Test case for convert_document_xlsx_to_pdf

        Excel XLSX to PDF  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_convert_api_client
from cloudmersive_convert_api_client.api.zip_archive_api import ZipArchiveApi  # noqa: E501
from cloudmersive_convert_api_client.rest import ApiException


class TestZipArchiveApi(unittest.TestCase):
    """ZipArchiveApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_convert_api_client.api.zip_archive_api.ZipArchiveApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_zip_archive_zip_create(self):
        """Test case for zip_archive_zip_create

        Compress files to create a new zip archive  # noqa: E501
        """
        pass

    def test_zip_archive_zip_create_advanced(self):
        """Test case for zip_archive_zip_create_advanced

        Compress files and folders to create a new zip archive with advanced options  # noqa: E501
        """
        pass

    def test_zip_archive_zip_extract(self):
        """Test case for zip_archive_zip_extract

        Extract, decompress files and folders from a zip archive  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DocxParagraph(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'paragraph_index': 'int',
        'path': 'str',
        'content_runs': 'list[DocxRun]',
        'style_id': 'str'
    }

    attribute_map = {
        'paragraph_index': 'ParagraphIndex',
        'path': 'Path',
        'content_runs': 'ContentRuns',
        'style_id': 'StyleID'
    }

    def __init__(self, paragraph_index=None, path=None, content_runs=None, style_id=None):  # noqa: E501
        """DocxParagraph - a model defined in Swagger"""  # noqa: E501

        self._paragraph_index = None
        self._path = None
        self._content_runs = None
        self._style_id = None
        self.discriminator = None

        if paragraph_index is not None:
            self.paragraph_index = paragraph_index
        if path is not None:
            self.path = path
        if content_runs is not None:
            self.content_runs = content_runs
        if style_id is not None:
            self.style_id = style_id

    @property
    def paragraph_index(self):
        """Gets the paragraph_index of this DocxParagraph.  # noqa: E501

        The index of the paragraph; 0-based  # noqa: E501

        :return: The paragraph_index of this DocxParagraph.  # noqa: E501
        :rtype: int
        """
        return self._paragraph_index

    @paragraph_index.setter
    def paragraph_index(self, paragraph_index):
        """Sets the paragraph_index of this DocxParagraph.

        The index of the paragraph; 0-based  # noqa: E501

        :param paragraph_index: The paragraph_index of this DocxParagraph.  # noqa: E501
        :type: int
        """

        self._paragraph_index = paragraph_index

    @property
    def path(self):
        """Gets the path of this DocxParagraph.  # noqa: E501

        The Path of the location of this Paragraph object; leave blank during creation  # noqa: E501

        :return: The path of this DocxParagraph.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this DocxParagraph.

        The Path of the location of this Paragraph object; leave blank during creation  # noqa: E501

        :param path: The path of this DocxParagraph.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def content_runs(self):
        """Gets the content_runs of this DocxParagraph.  # noqa: E501

        The content runs in the paragraph - this is where text is stored; similar to a span in HTML  # noqa: E501

        :return: The content_runs of this DocxParagraph.  # noqa: E501
        :rtype: list[DocxRun]
        """
        return self._content_runs

    @content_runs.setter
    def content_runs(self, content_runs):
        """Sets the content_runs of this DocxParagraph.

        The content runs in the paragraph - this is where text is stored; similar to a span in HTML  # noqa: E501

        :param content_runs: The content_runs of this DocxParagraph.  # noqa: E501
        :type: list[DocxRun]
        """

        self._content_runs = content_runs

    @property
    def style_id(self):
        """Gets the style_id of this DocxParagraph.  # noqa: E501

        Style ID of the style applied to the paragraph; null if no style is applied  # noqa: E501

        :return: The style_id of this DocxParagraph.  # noqa: E501
        :rtype: str
        """
        return self._style_id

    @style_id.setter
    def style_id(self, style_id):
        """Sets the style_id of this DocxParagraph.

        Style ID of the style applied to the paragraph; null if no style is applied  # noqa: E501

        :param style_id: The style_id of this DocxParagraph.  # noqa: E501
        :type: str
        """

        self._style_id = style_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocxParagraph, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocxParagraph):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GetImageInfoResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'successful': 'bool',
        'color_space': 'str',
        'color_type': 'str',
        'width': 'int',
        'height': 'int',
        'compression_level': 'int',
        'image_hash_signature': 'str',
        'has_transparency': 'bool',
        'mime_type': 'str',
        'image_format': 'str',
        'dpi_unit': 'str',
        'dpi': 'float',
        'color_count': 'int',
        'bit_depth': 'int',
        'comment': 'str',
        'exif_profile_name': 'str',
        'exif_values': 'list[ExifValue]'
    }

    attribute_map = {
        'successful': 'Successful',
        'color_space': 'ColorSpace',
        'color_type': 'ColorType',
        'width': 'Width',
        'height': 'Height',
        'compression_level': 'CompressionLevel',
        'image_hash_signature': 'ImageHashSignature',
        'has_transparency': 'HasTransparency',
        'mime_type': 'MimeType',
        'image_format': 'ImageFormat',
        'dpi_unit': 'DPIUnit',
        'dpi': 'DPI',
        'color_count': 'ColorCount',
        'bit_depth': 'BitDepth',
        'comment': 'Comment',
        'exif_profile_name': 'ExifProfileName',
        'exif_values': 'ExifValues'
    }

    def __init__(self, successful=None, color_space=None, color_type=None, width=None, height=None, compression_level=None, image_hash_signature=None, has_transparency=None, mime_type=None, image_format=None, dpi_unit=None, dpi=None, color_count=None, bit_depth=None, comment=None, exif_profile_name=None, exif_values=None):  # noqa: E501
        """GetImageInfoResult - a model defined in Swagger"""  # noqa: E501

        self._successful = None
        self._color_space = None
        self._color_type = None
        self._width = None
        self._height = None
        self._compression_level = None
        self._image_hash_signature = None
        self._has_transparency = None
        self._mime_type = None
        self._image_format = None
        self._dpi_unit = None
        self._dpi = None
        self._color_count = None
        self._bit_depth = None
        self._comment = None
        self._exif_profile_name = None
        self._exif_values = None
        self.discriminator = None

        if successful is not None:
            self.successful = successful
        if color_space is not None:
            self.color_space = color_space
        if color_type is not None:
            self.color_type = color_type
        if width is not None:
            self.width = width
        if height is not None:
            self.height = height
        if compression_level is not None:
            self.compression_level = compression_level
        if image_hash_signature is not None:
            self.image_hash_signature = image_hash_signature
        if has_transparency is not None:
            self.has_transparency = has_transparency
        if mime_type is not None:
            self.mime_type = mime_type
        if image_format is not None:
            self.image_format = image_format
        if dpi_unit is not None:
            self.dpi_unit = dpi_unit
        if dpi is not None:
            self.dpi = dpi
        if color_count is not None:
            self.color_count = color_count
        if bit_depth is not None:
            self.bit_depth = bit_depth
        if comment is not None:
            self.comment = comment
        if exif_profile_name is not None:
            self.exif_profile_name = exif_profile_name
        if exif_values is not None:
            self.exif_values = exif_values

    @property
    def successful(self):
        """Gets the successful of this GetImageInfoResult.  # noqa: E501


        :return: The successful of this GetImageInfoResult.  # noqa: E501
        :rtype: bool
        """
        return self._successful

    @successful.setter
    def successful(self, successful):
        """Sets the successful of this GetImageInfoResult.


        :param successful: The successful of this GetImageInfoResult.  # noqa: E501
        :type: bool
        """

        self._successful = successful

    @property
    def color_space(self):
        """Gets the color_space of this GetImageInfoResult.  # noqa: E501

        Color space of the image  # noqa: E501

        :return: The color_space of this GetImageInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._color_space

    @color_space.setter
    def color_space(self, color_space):
        """Sets the color_space of this GetImageInfoResult.

        Color space of the image  # noqa: E501

        :param color_space: The color_space of this GetImageInfoResult.  # noqa: E501
        :type: str
        """

        self._color_space = color_space

    @property
    def color_type(self):
        """Gets the color_type of this GetImageInfoResult.  # noqa: E501

        Color type of the image  # noqa: E501

        :return: The color_type of this GetImageInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._color_type

    @color_type.setter
    def color_type(self, color_type):
        """Sets the color_type of this GetImageInfoResult.

        Color type of the image  # noqa: E501

        :param color_type: The color_type of this GetImageInfoResult.  # noqa: E501
        :type: str
        """

        self._color_type = color_type

    @property
    def width(self):
        """Gets the width of this GetImageInfoResult.  # noqa: E501

        Width in pixels of the image  # noqa: E501

        :return: The width of this GetImageInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this GetImageInfoResult.

        Width in pixels of the image  # noqa: E501

        :param width: The width of this GetImageInfoResult.  # noqa: E501
        :type: int
        """

        self._width = width

    @property
    def height(self):
        """Gets the height of this GetImageInfoResult.  # noqa: E501

        Height in pixels of the image  # noqa: E501

        :return: The height of this GetImageInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this GetImageInfoResult.

        Height in pixels of the image  # noqa: E501

        :param height: The height of this GetImageInfoResult.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def compression_level(self):
        """Gets the compression_level of this GetImageInfoResult.  # noqa: E501

        Compression level value from 0 (lowest quality) to 100 (highest quality)  # noqa: E501

        :return: The compression_level of this GetImageInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._compression_level

    @compression_level.setter
    def compression_level(self, compression_level):
        """Sets the compression_level of this GetImageInfoResult.

        Compression level value from 0 (lowest quality) to 100 (highest quality)  # noqa: E501

        :param compression_level: The compression_level of this GetImageInfoResult.  # noqa: E501
        :type: int
        """

        self._compression_level = compression_level

    @property
    def image_hash_signature(self):
        """Gets the image_hash_signature of this GetImageInfoResult.  # noqa: E501

        SHA256 hash signature of the image  # noqa: E501

        :return: The image_hash_signature of this GetImageInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._image_hash_signature

    @image_hash_signature.setter
    def image_hash_signature(self, image_hash_signature):
        """Sets the image_hash_signature of this GetImageInfoResult.

        SHA256 hash signature of the image  # noqa: E501

        :param image_hash_signature: The image_hash_signature of this GetImageInfoResult.  # noqa: E501
        :type: str
        """

        self._image_hash_signature = image_hash_signature

    @property
    def has_transparency(self):
        """Gets the has_transparency of this GetImageInfoResult.  # noqa: E501

        True if the image contains transparency, otherwise false  # noqa: E501

        :return: The has_transparency of this GetImageInfoResult.  # noqa: E501
        :rtype: bool
        """
        return self._has_transparency

    @has_transparency.setter
    def has_transparency(self, has_transparency):
        """Sets the has_transparency of this GetImageInfoResult.

        True if the image contains transparency, otherwise false  # noqa: E501

        :param has_transparency: The has_transparency of this GetImageInfoResult.  # noqa: E501
        :type: bool
        """

        self._has_transparency = has_transparency

    @property
    def mime_type(self):
        """Gets the mime_type of this GetImageInfoResult.  # noqa: E501

        MIME type of the image format  # noqa: E501

        :return: The mime_type of this GetImageInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """Sets the mime_type of this GetImageInfoResult.

        MIME type of the image format  # noqa: E501

        :param mime_type: The mime_type of this GetImageInfoResult.  # noqa: E501
        :type: str
        """

        self._mime_type = mime_type

    @property
    def image_format(self):
        """Gets the image_format of this GetImageInfoResult.  # noqa: E501

        Image format  # noqa: E501

        :return: The image_format of this GetImageInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._image_format

    @image_format.setter
    def image_format(self, image_format):
        """Sets the image_format of this GetImageInfoResult.

        Image format  # noqa: E501

        :param image_format: The image_format of this GetImageInfoResult.  # noqa: E501
        :type: str
        """

        self._image_format = image_format

    @property
    def dpi_unit(self):
        """Gets the dpi_unit of this GetImageInfoResult.  # noqa: E501

        Units of the DPI measurement; can be either in Inches or Centimeters  # noqa: E501

        :return: The dpi_unit of this GetImageInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._dpi_unit

    @dpi_unit.setter
    def dpi_unit(self, dpi_unit):
        """Sets the dpi_unit of this GetImageInfoResult.

        Units of the DPI measurement; can be either in Inches or Centimeters  # noqa: E501

        :param dpi_unit: The dpi_unit of this GetImageInfoResult.  # noqa: E501
        :type: str
        """

        self._dpi_unit = dpi_unit

    @property
    def dpi(self):
        """Gets the dpi of this GetImageInfoResult.  # noqa: E501

        DPI (pixels per unit, e.g. pixels per inch) of the image  # noqa: E501

        :return: The dpi of this GetImageInfoResult.  # noqa: E501
        :rtype: float
        """
        return self._dpi

    @dpi.setter
    def dpi(self, dpi):
        """Sets the dpi of this GetImageInfoResult.

        DPI (pixels per unit, e.g. pixels per inch) of the image  # noqa: E501

        :param dpi: The dpi of this GetImageInfoResult.  # noqa: E501
        :type: float
        """

        self._dpi = dpi

    @property
    def color_count(self):
        """Gets the color_count of this GetImageInfoResult.  # noqa: E501

        Unique colors in the image  # noqa: E501

        :return: The color_count of this GetImageInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._color_count

    @color_count.setter
    def color_count(self, color_count):
        """Sets the color_count of this GetImageInfoResult.

        Unique colors in the image  # noqa: E501

        :param color_count: The color_count of this GetImageInfoResult.  # noqa: E501
        :type: int
        """

        self._color_count = color_count

    @property
    def bit_depth(self):
        """Gets the bit_depth of this GetImageInfoResult.  # noqa: E501

        Bit depth of the image  # noqa: E501

        :return: The bit_depth of this GetImageInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._bit_depth

    @bit_depth.setter
    def bit_depth(self, bit_depth):
        """Sets the bit_depth of this GetImageInfoResult.

        Bit depth of the image  # noqa: E501

        :param bit_depth: The bit_depth of this GetImageInfoResult.  # noqa: E501
        :type: int
        """

        self._bit_depth = bit_depth

    @property
    def comment(self):
        """Gets the comment of this GetImageInfoResult.  # noqa: E501

        Comment string in the image  # noqa: E501

        :return: The comment of this GetImageInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this GetImageInfoResult.

        Comment string in the image  # noqa: E501

        :param comment: The comment of this GetImageInfoResult.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def exif_profile_name(self):
        """Gets the exif_profile_name of this GetImageInfoResult.  # noqa: E501

        Name of the EXIF profile used  # noqa: E501

        :return: The exif_profile_name of this GetImageInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._exif_profile_name

    @exif_profile_name.setter
    def exif_profile_name(self, exif_profile_name):
        """Sets the exif_profile_name of this GetImageInfoResult.

        Name of the EXIF profile used  # noqa: E501

        :param exif_profile_name: The exif_profile_name of this GetImageInfoResult.  # noqa: E501
        :type: str
        """

        self._exif_profile_name = exif_profile_name

    @property
    def exif_values(self):
        """Gets the exif_values of this GetImageInfoResult.  # noqa: E501

        EXIF tags and values embedded in the image  # noqa: E501

        :return: The exif_values of this GetImageInfoResult.  # noqa: E501
        :rtype: list[ExifValue]
        """
        return self._exif_values

    @exif_values.setter
    def exif_values(self, exif_values):
        """Sets the exif_values of this GetImageInfoResult.

        EXIF tags and values embedded in the image  # noqa: E501

        :param exif_values: The exif_values of this GetImageInfoResult.  # noqa: E501
        :type: list[ExifValue]
        """

        self._exif_values = exif_values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetImageInfoResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetImageInfoResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cloudmersive_convert_api_client.api_client import ApiClient


class EditTextApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def edit_text_base64_decode(self, request, **kwargs):  # noqa: E501
        """Base 64 decode, convert base 64 string to binary content  # noqa: E501

        Decodes / converts base 64 UTF-8 text string to binary content  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_base64_decode(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Base64DecodeRequest request: Input request (required)
        :return: Base64DecodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_text_base64_decode_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_text_base64_decode_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def edit_text_base64_decode_with_http_info(self, request, **kwargs):  # noqa: E501
        """Base 64 decode, convert base 64 string to binary content  # noqa: E501

        Decodes / converts base 64 UTF-8 text string to binary content  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_base64_decode_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Base64DecodeRequest request: Input request (required)
        :return: Base64DecodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_text_base64_decode" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `edit_text_base64_decode`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/text/encoding/base64/decode', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Base64DecodeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_text_base64_detect(self, request, **kwargs):  # noqa: E501
        """Detect, check if text string is base 64 encoded  # noqa: E501

        Checks, detects if input string is base 64 encoded  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_base64_detect(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Base64DetectRequest request: Input request (required)
        :return: Base64DetectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_text_base64_detect_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_text_base64_detect_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def edit_text_base64_detect_with_http_info(self, request, **kwargs):  # noqa: E501
        """Detect, check if text string is base 64 encoded  # noqa: E501

        Checks, detects if input string is base 64 encoded  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_base64_detect_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Base64DetectRequest request: Input request (required)
        :return: Base64DetectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_text_base64_detect" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `edit_text_base64_detect`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/text/encoding/base64/detect', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Base64DetectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_text_base64_encode(self, request, **kwargs):  # noqa: E501
        """Base 64 encode, convert binary or file data to a text string  # noqa: E501

        Encodes / converts binary or file data to a text string  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_base64_encode(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Base64EncodeRequest request: Input request (required)
        :return: Base64EncodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_text_base64_encode_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_text_base64_encode_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def edit_text_base64_encode_with_http_info(self, request, **kwargs):  # noqa: E501
        """Base 64 encode, convert binary or file data to a text string  # noqa: E501

        Encodes / converts binary or file data to a text string  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_base64_encode_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Base64EncodeRequest request: Input request (required)
        :return: Base64EncodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_text_base64_encode" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `edit_text_base64_encode`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/text/encoding/base64/encode', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Base64EncodeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_text_change_line_endings(self, line_ending_type, input_file, **kwargs):  # noqa: E501
        """Set, change line endings of a text file  # noqa: E501

        Sets the line ending type of a text file; set to Windows, Unix or Mac.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_change_line_endings(line_ending_type, input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str line_ending_type: Required; 'Windows' will use carriage return and line feed, 'Unix' will use newline, and 'Mac' will use carriage return (required)
        :param file input_file: Input file to perform the operation on. (required)
        :return: ChangeLineEndingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_text_change_line_endings_with_http_info(line_ending_type, input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_text_change_line_endings_with_http_info(line_ending_type, input_file, **kwargs)  # noqa: E501
            return data

    def edit_text_change_line_endings_with_http_info(self, line_ending_type, input_file, **kwargs):  # noqa: E501
        """Set, change line endings of a text file  # noqa: E501

        Sets the line ending type of a text file; set to Windows, Unix or Mac.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_change_line_endings_with_http_info(line_ending_type, input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str line_ending_type: Required; 'Windows' will use carriage return and line feed, 'Unix' will use newline, and 'Mac' will use carriage return (required)
        :param file input_file: Input file to perform the operation on. (required)
        :return: ChangeLineEndingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['line_ending_type', 'input_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_text_change_line_endings" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'line_ending_type' is set
        if ('line_ending_type' not in params or
                params['line_ending_type'] is None):
            raise ValueError("Missing the required parameter `line_ending_type` when calling `edit_text_change_line_endings`")  # noqa: E501
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `edit_text_change_line_endings`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'line_ending_type' in params:
            header_params['lineEndingType'] = params['line_ending_type']  # noqa: E501

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/text/line-endings/change', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ChangeLineEndingResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_text_detect_line_endings(self, input_file, **kwargs):  # noqa: E501
        """Detect line endings of a text file  # noqa: E501

        Detect line ending type (Windows, Unix or Mac) of an input file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_detect_line_endings(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: DetectLineEndingsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_text_detect_line_endings_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_text_detect_line_endings_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def edit_text_detect_line_endings_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Detect line endings of a text file  # noqa: E501

        Detect line ending type (Windows, Unix or Mac) of an input file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_detect_line_endings_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: DetectLineEndingsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_text_detect_line_endings" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `edit_text_detect_line_endings`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/text/line-endings/detect', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DetectLineEndingsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_text_find_regex(self, request, **kwargs):  # noqa: E501
        """Find a regular expression regex in text input  # noqa: E501

        Find all occurrences of the input regular expression in the input content, and returns the matches  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_find_regex(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FindStringRegexRequest request: Input request (required)
        :return: FindStringRegexResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_text_find_regex_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_text_find_regex_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def edit_text_find_regex_with_http_info(self, request, **kwargs):  # noqa: E501
        """Find a regular expression regex in text input  # noqa: E501

        Find all occurrences of the input regular expression in the input content, and returns the matches  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_find_regex_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FindStringRegexRequest request: Input request (required)
        :return: FindStringRegexResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_text_find_regex" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `edit_text_find_regex`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/text/find/regex', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FindStringRegexResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_text_find_simple(self, request, **kwargs):  # noqa: E501
        """Find a string in text input  # noqa: E501

        Finds all occurrences of the input string in the input content, and returns the matches  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_find_simple(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FindStringSimpleRequest request: Input request (required)
        :return: FindStringSimpleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_text_find_simple_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_text_find_simple_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def edit_text_find_simple_with_http_info(self, request, **kwargs):  # noqa: E501
        """Find a string in text input  # noqa: E501

        Finds all occurrences of the input string in the input content, and returns the matches  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_find_simple_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FindStringSimpleRequest request: Input request (required)
        :return: FindStringSimpleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_text_find_simple" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `edit_text_find_simple`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/text/find/string', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FindStringSimpleResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_text_remove_all_whitespace(self, request, **kwargs):  # noqa: E501
        """Remove whitespace from text string  # noqa: E501

        Removes all whitespace from text, leaving behind only non-whitespace characters.  Whitespace includes newlines, spaces and other whitespace characters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_remove_all_whitespace(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoveWhitespaceFromTextRequest request: Input request (required)
        :return: RemoveWhitespaceFromTextResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_text_remove_all_whitespace_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_text_remove_all_whitespace_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def edit_text_remove_all_whitespace_with_http_info(self, request, **kwargs):  # noqa: E501
        """Remove whitespace from text string  # noqa: E501

        Removes all whitespace from text, leaving behind only non-whitespace characters.  Whitespace includes newlines, spaces and other whitespace characters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_remove_all_whitespace_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoveWhitespaceFromTextRequest request: Input request (required)
        :return: RemoveWhitespaceFromTextResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_text_remove_all_whitespace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `edit_text_remove_all_whitespace`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/text/remove/whitespace/all', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RemoveWhitespaceFromTextResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_text_remove_html(self, request, **kwargs):  # noqa: E501
        """Remove HTML from text string  # noqa: E501

        Removes HTML from text, leaving behind only text.  Formatted text will become plain text.  Important for protecting against HTML and Cross-Site-Scripting attacks.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_remove_html(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoveHtmlFromTextRequest request: Input request (required)
        :return: RemoveHtmlFromTextResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_text_remove_html_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_text_remove_html_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def edit_text_remove_html_with_http_info(self, request, **kwargs):  # noqa: E501
        """Remove HTML from text string  # noqa: E501

        Removes HTML from text, leaving behind only text.  Formatted text will become plain text.  Important for protecting against HTML and Cross-Site-Scripting attacks.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_remove_html_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoveHtmlFromTextRequest request: Input request (required)
        :return: RemoveHtmlFromTextResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_text_remove_html" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `edit_text_remove_html`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/text/remove/html', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RemoveHtmlFromTextResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_text_replace_regex(self, request, **kwargs):  # noqa: E501
        """Replace a string in text with a regex regular expression string  # noqa: E501

        Replaces all occurrences of the input regular expression regex string in the input content, and returns the result  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_replace_regex(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ReplaceStringRegexRequest request: Input request (required)
        :return: ReplaceStringRegexResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_text_replace_regex_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_text_replace_regex_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def edit_text_replace_regex_with_http_info(self, request, **kwargs):  # noqa: E501
        """Replace a string in text with a regex regular expression string  # noqa: E501

        Replaces all occurrences of the input regular expression regex string in the input content, and returns the result  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_replace_regex_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ReplaceStringRegexRequest request: Input request (required)
        :return: ReplaceStringRegexResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_text_replace_regex" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `edit_text_replace_regex`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/text/replace/regex', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ReplaceStringRegexResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_text_replace_simple(self, request, **kwargs):  # noqa: E501
        """Replace a string in text with another string value  # noqa: E501

        Replaces all occurrences of the input string in the input content, and returns the result  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_replace_simple(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ReplaceStringSimpleRequest request: Input request (required)
        :return: ReplaceStringSimpleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_text_replace_simple_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_text_replace_simple_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def edit_text_replace_simple_with_http_info(self, request, **kwargs):  # noqa: E501
        """Replace a string in text with another string value  # noqa: E501

        Replaces all occurrences of the input string in the input content, and returns the result  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_replace_simple_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ReplaceStringSimpleRequest request: Input request (required)
        :return: ReplaceStringSimpleResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_text_replace_simple" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `edit_text_replace_simple`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/text/replace/string', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ReplaceStringSimpleResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_text_text_encoding_detect(self, input_file, **kwargs):  # noqa: E501
        """Detect text encoding of file  # noqa: E501

        Checks text encoding of file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_text_encoding_detect(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: TextEncodingDetectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_text_text_encoding_detect_with_http_info(input_file, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_text_text_encoding_detect_with_http_info(input_file, **kwargs)  # noqa: E501
            return data

    def edit_text_text_encoding_detect_with_http_info(self, input_file, **kwargs):  # noqa: E501
        """Detect text encoding of file  # noqa: E501

        Checks text encoding of file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_text_encoding_detect_with_http_info(input_file, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file input_file: Input file to perform the operation on. (required)
        :return: TextEncodingDetectResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['input_file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_text_text_encoding_detect" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'input_file' is set
        if ('input_file' not in params or
                params['input_file'] is None):
            raise ValueError("Missing the required parameter `input_file` when calling `edit_text_text_encoding_detect`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'input_file' in params:
            local_var_files['inputFile'] = params['input_file']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/text/encoding/detect', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TextEncodingDetectResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def edit_text_trim_whitespace(self, request, **kwargs):  # noqa: E501
        """Trim leading and trailing whitespace from text string  # noqa: E501

        Trim leading and trailing whitespace from text, leaving behind a trimmed string.  Whitespace includes newlines, spaces and other whitespace characters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_trim_whitespace(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoveWhitespaceFromTextRequest request: Input request (required)
        :return: RemoveWhitespaceFromTextResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.edit_text_trim_whitespace_with_http_info(request, **kwargs)  # noqa: E501
        else:
            (data) = self.edit_text_trim_whitespace_with_http_info(request, **kwargs)  # noqa: E501
            return data

    def edit_text_trim_whitespace_with_http_info(self, request, **kwargs):  # noqa: E501
        """Trim leading and trailing whitespace from text string  # noqa: E501

        Trim leading and trailing whitespace from text, leaving behind a trimmed string.  Whitespace includes newlines, spaces and other whitespace characters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.edit_text_trim_whitespace_with_http_info(request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoveWhitespaceFromTextRequest request: Input request (required)
        :return: RemoveWhitespaceFromTextResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method edit_text_trim_whitespace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'request' is set
        if ('request' not in params or
                params['request'] is None):
            raise ValueError("Missing the required parameter `request` when calling `edit_text_trim_whitespace`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request' in params:
            body_params = params['request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json', 'application/xml', 'text/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/xml', 'text/xml', 'application/x-www-form-urlencoded'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Apikey']  # noqa: E501

        return self.api_client.call_api(
            '/convert/edit/text/remove/whitespace/trim', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RemoveWhitespaceFromTextResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class AutodetectGetInfoResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'successful': 'bool',
        'detected_file_extension': 'str',
        'detected_mime_type': 'str',
        'page_count': 'int',
        'author': 'str',
        'date_modified': 'datetime',
        'alternate_file_type_candidates': 'list[AlternateFileFormatCandidate]'
    }

    attribute_map = {
        'successful': 'Successful',
        'detected_file_extension': 'DetectedFileExtension',
        'detected_mime_type': 'DetectedMimeType',
        'page_count': 'PageCount',
        'author': 'Author',
        'date_modified': 'DateModified',
        'alternate_file_type_candidates': 'AlternateFileTypeCandidates'
    }

    def __init__(self, successful=None, detected_file_extension=None, detected_mime_type=None, page_count=None, author=None, date_modified=None, alternate_file_type_candidates=None):  # noqa: E501
        """AutodetectGetInfoResult - a model defined in Swagger"""  # noqa: E501

        self._successful = None
        self._detected_file_extension = None
        self._detected_mime_type = None
        self._page_count = None
        self._author = None
        self._date_modified = None
        self._alternate_file_type_candidates = None
        self.discriminator = None

        if successful is not None:
            self.successful = successful
        if detected_file_extension is not None:
            self.detected_file_extension = detected_file_extension
        if detected_mime_type is not None:
            self.detected_mime_type = detected_mime_type
        if page_count is not None:
            self.page_count = page_count
        if author is not None:
            self.author = author
        if date_modified is not None:
            self.date_modified = date_modified
        if alternate_file_type_candidates is not None:
            self.alternate_file_type_candidates = alternate_file_type_candidates

    @property
    def successful(self):
        """Gets the successful of this AutodetectGetInfoResult.  # noqa: E501

        True if the operation was successful, false otherwise  # noqa: E501

        :return: The successful of this AutodetectGetInfoResult.  # noqa: E501
        :rtype: bool
        """
        return self._successful

    @successful.setter
    def successful(self, successful):
        """Sets the successful of this AutodetectGetInfoResult.

        True if the operation was successful, false otherwise  # noqa: E501

        :param successful: The successful of this AutodetectGetInfoResult.  # noqa: E501
        :type: bool
        """

        self._successful = successful

    @property
    def detected_file_extension(self):
        """Gets the detected_file_extension of this AutodetectGetInfoResult.  # noqa: E501

        Detected file extension of the file format, with a leading period  # noqa: E501

        :return: The detected_file_extension of this AutodetectGetInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._detected_file_extension

    @detected_file_extension.setter
    def detected_file_extension(self, detected_file_extension):
        """Sets the detected_file_extension of this AutodetectGetInfoResult.

        Detected file extension of the file format, with a leading period  # noqa: E501

        :param detected_file_extension: The detected_file_extension of this AutodetectGetInfoResult.  # noqa: E501
        :type: str
        """

        self._detected_file_extension = detected_file_extension

    @property
    def detected_mime_type(self):
        """Gets the detected_mime_type of this AutodetectGetInfoResult.  # noqa: E501

        MIME type of this file extension  # noqa: E501

        :return: The detected_mime_type of this AutodetectGetInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._detected_mime_type

    @detected_mime_type.setter
    def detected_mime_type(self, detected_mime_type):
        """Sets the detected_mime_type of this AutodetectGetInfoResult.

        MIME type of this file extension  # noqa: E501

        :param detected_mime_type: The detected_mime_type of this AutodetectGetInfoResult.  # noqa: E501
        :type: str
        """

        self._detected_mime_type = detected_mime_type

    @property
    def page_count(self):
        """Gets the page_count of this AutodetectGetInfoResult.  # noqa: E501

        Number of pages in a page-based document; for presentations, this is the number of slides and for a spreadsheet this is the number of worksheets.  Contains 0 when the page count cannot be determined, or if the concept of page count does not apply (e.g. for an image)  # noqa: E501

        :return: The page_count of this AutodetectGetInfoResult.  # noqa: E501
        :rtype: int
        """
        return self._page_count

    @page_count.setter
    def page_count(self, page_count):
        """Sets the page_count of this AutodetectGetInfoResult.

        Number of pages in a page-based document; for presentations, this is the number of slides and for a spreadsheet this is the number of worksheets.  Contains 0 when the page count cannot be determined, or if the concept of page count does not apply (e.g. for an image)  # noqa: E501

        :param page_count: The page_count of this AutodetectGetInfoResult.  # noqa: E501
        :type: int
        """

        self._page_count = page_count

    @property
    def author(self):
        """Gets the author of this AutodetectGetInfoResult.  # noqa: E501

        User name of the creator/author of the document, if available, null if not available  # noqa: E501

        :return: The author of this AutodetectGetInfoResult.  # noqa: E501
        :rtype: str
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this AutodetectGetInfoResult.

        User name of the creator/author of the document, if available, null if not available  # noqa: E501

        :param author: The author of this AutodetectGetInfoResult.  # noqa: E501
        :type: str
        """

        self._author = author

    @property
    def date_modified(self):
        """Gets the date_modified of this AutodetectGetInfoResult.  # noqa: E501

        The timestamp that the document was last modified, if available, null if not available  # noqa: E501

        :return: The date_modified of this AutodetectGetInfoResult.  # noqa: E501
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """Sets the date_modified of this AutodetectGetInfoResult.

        The timestamp that the document was last modified, if available, null if not available  # noqa: E501

        :param date_modified: The date_modified of this AutodetectGetInfoResult.  # noqa: E501
        :type: datetime
        """

        self._date_modified = date_modified

    @property
    def alternate_file_type_candidates(self):
        """Gets the alternate_file_type_candidates of this AutodetectGetInfoResult.  # noqa: E501

        Alternate file type options and their probability  # noqa: E501

        :return: The alternate_file_type_candidates of this AutodetectGetInfoResult.  # noqa: E501
        :rtype: list[AlternateFileFormatCandidate]
        """
        return self._alternate_file_type_candidates

    @alternate_file_type_candidates.setter
    def alternate_file_type_candidates(self, alternate_file_type_candidates):
        """Sets the alternate_file_type_candidates of this AutodetectGetInfoResult.

        Alternate file type options and their probability  # noqa: E501

        :param alternate_file_type_candidates: The alternate_file_type_candidates of this AutodetectGetInfoResult.  # noqa: E501
        :type: list[AlternateFileFormatCandidate]
        """

        self._alternate_file_type_candidates = alternate_file_type_candidates

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AutodetectGetInfoResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AutodetectGetInfoResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DocxInsertImageRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'input_document_file_bytes': 'str',
        'input_document_file_url': 'str',
        'input_image_file_bytes': 'str',
        'input_image_file_url': 'str',
        'image_to_add': 'DocxImage',
        'insert_placement': 'str',
        'insert_path': 'str',
        'width_in_em_us': 'int',
        'height_in_em_us': 'int'
    }

    attribute_map = {
        'input_document_file_bytes': 'InputDocumentFileBytes',
        'input_document_file_url': 'InputDocumentFileUrl',
        'input_image_file_bytes': 'InputImageFileBytes',
        'input_image_file_url': 'InputImageFileUrl',
        'image_to_add': 'ImageToAdd',
        'insert_placement': 'InsertPlacement',
        'insert_path': 'InsertPath',
        'width_in_em_us': 'WidthInEMUs',
        'height_in_em_us': 'HeightInEMUs'
    }

    def __init__(self, input_document_file_bytes=None, input_document_file_url=None, input_image_file_bytes=None, input_image_file_url=None, image_to_add=None, insert_placement=None, insert_path=None, width_in_em_us=None, height_in_em_us=None):  # noqa: E501
        """DocxInsertImageRequest - a model defined in Swagger"""  # noqa: E501

        self._input_document_file_bytes = None
        self._input_document_file_url = None
        self._input_image_file_bytes = None
        self._input_image_file_url = None
        self._image_to_add = None
        self._insert_placement = None
        self._insert_path = None
        self._width_in_em_us = None
        self._height_in_em_us = None
        self.discriminator = None

        if input_document_file_bytes is not None:
            self.input_document_file_bytes = input_document_file_bytes
        if input_document_file_url is not None:
            self.input_document_file_url = input_document_file_url
        if input_image_file_bytes is not None:
            self.input_image_file_bytes = input_image_file_bytes
        if input_image_file_url is not None:
            self.input_image_file_url = input_image_file_url
        if image_to_add is not None:
            self.image_to_add = image_to_add
        if insert_placement is not None:
            self.insert_placement = insert_placement
        if insert_path is not None:
            self.insert_path = insert_path
        if width_in_em_us is not None:
            self.width_in_em_us = width_in_em_us
        if height_in_em_us is not None:
            self.height_in_em_us = height_in_em_us

    @property
    def input_document_file_bytes(self):
        """Gets the input_document_file_bytes of this DocxInsertImageRequest.  # noqa: E501

        Optional: Bytes of the input file to operate on  # noqa: E501

        :return: The input_document_file_bytes of this DocxInsertImageRequest.  # noqa: E501
        :rtype: str
        """
        return self._input_document_file_bytes

    @input_document_file_bytes.setter
    def input_document_file_bytes(self, input_document_file_bytes):
        """Sets the input_document_file_bytes of this DocxInsertImageRequest.

        Optional: Bytes of the input file to operate on  # noqa: E501

        :param input_document_file_bytes: The input_document_file_bytes of this DocxInsertImageRequest.  # noqa: E501
        :type: str
        """
        if input_document_file_bytes is not None and not re.search(r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', input_document_file_bytes):  # noqa: E501
            raise ValueError(r"Invalid value for `input_document_file_bytes`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._input_document_file_bytes = input_document_file_bytes

    @property
    def input_document_file_url(self):
        """Gets the input_document_file_url of this DocxInsertImageRequest.  # noqa: E501

        Optional: URL of a file to operate on as input.  This can be a public URL, or you can also use the begin-editing API to upload a document and pass in the secure URL result from that operation as the URL here (this URL is not public).  # noqa: E501

        :return: The input_document_file_url of this DocxInsertImageRequest.  # noqa: E501
        :rtype: str
        """
        return self._input_document_file_url

    @input_document_file_url.setter
    def input_document_file_url(self, input_document_file_url):
        """Sets the input_document_file_url of this DocxInsertImageRequest.

        Optional: URL of a file to operate on as input.  This can be a public URL, or you can also use the begin-editing API to upload a document and pass in the secure URL result from that operation as the URL here (this URL is not public).  # noqa: E501

        :param input_document_file_url: The input_document_file_url of this DocxInsertImageRequest.  # noqa: E501
        :type: str
        """

        self._input_document_file_url = input_document_file_url

    @property
    def input_image_file_bytes(self):
        """Gets the input_image_file_bytes of this DocxInsertImageRequest.  # noqa: E501

        Optional: Bytes of the input image file to operate on; if you supply this value do not supply InputImageFileUrl or ImageToAdd.  # noqa: E501

        :return: The input_image_file_bytes of this DocxInsertImageRequest.  # noqa: E501
        :rtype: str
        """
        return self._input_image_file_bytes

    @input_image_file_bytes.setter
    def input_image_file_bytes(self, input_image_file_bytes):
        """Sets the input_image_file_bytes of this DocxInsertImageRequest.

        Optional: Bytes of the input image file to operate on; if you supply this value do not supply InputImageFileUrl or ImageToAdd.  # noqa: E501

        :param input_image_file_bytes: The input_image_file_bytes of this DocxInsertImageRequest.  # noqa: E501
        :type: str
        """
        if input_image_file_bytes is not None and not re.search(r'^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$', input_image_file_bytes):  # noqa: E501
            raise ValueError(r"Invalid value for `input_image_file_bytes`, must be a follow pattern or equal to `/^(?:[A-Za-z0-9+\/]{4})*(?:[A-Za-z0-9+\/]{2}==|[A-Za-z0-9+\/]{3}=)?$/`")  # noqa: E501

        self._input_image_file_bytes = input_image_file_bytes

    @property
    def input_image_file_url(self):
        """Gets the input_image_file_url of this DocxInsertImageRequest.  # noqa: E501

        Optional: URL of an image file to operate on as input; if you supply this value do not supply InputImageFileBytes or ImageToAdd.  This can be a public URL, or you can also use the begin-editing API to upload a document and pass in the secure URL result from that operation as the URL here (this URL is not public).  # noqa: E501

        :return: The input_image_file_url of this DocxInsertImageRequest.  # noqa: E501
        :rtype: str
        """
        return self._input_image_file_url

    @input_image_file_url.setter
    def input_image_file_url(self, input_image_file_url):
        """Sets the input_image_file_url of this DocxInsertImageRequest.

        Optional: URL of an image file to operate on as input; if you supply this value do not supply InputImageFileBytes or ImageToAdd.  This can be a public URL, or you can also use the begin-editing API to upload a document and pass in the secure URL result from that operation as the URL here (this URL is not public).  # noqa: E501

        :param input_image_file_url: The input_image_file_url of this DocxInsertImageRequest.  # noqa: E501
        :type: str
        """

        self._input_image_file_url = input_image_file_url

    @property
    def image_to_add(self):
        """Gets the image_to_add of this DocxInsertImageRequest.  # noqa: E501

        Optional: Image to add; if you supply in this object, do not supply InputImageFileBytes or InputImageFileUrl.  # noqa: E501

        :return: The image_to_add of this DocxInsertImageRequest.  # noqa: E501
        :rtype: DocxImage
        """
        return self._image_to_add

    @image_to_add.setter
    def image_to_add(self, image_to_add):
        """Sets the image_to_add of this DocxInsertImageRequest.

        Optional: Image to add; if you supply in this object, do not supply InputImageFileBytes or InputImageFileUrl.  # noqa: E501

        :param image_to_add: The image_to_add of this DocxInsertImageRequest.  # noqa: E501
        :type: DocxImage
        """

        self._image_to_add = image_to_add

    @property
    def insert_placement(self):
        """Gets the insert_placement of this DocxInsertImageRequest.  # noqa: E501

        Optional; default is DocumentEnd.  Placement Type of the insert; possible values are: DocumentStart (very beginning of the document), DocumentEnd (very end of the document), BeforeExistingObject (right before an existing object - fill in the InsertPath field using the Path value from an existing object), AfterExistingObject (right after an existing object - fill in the InsertPath field using the Path value from an existing object)  # noqa: E501

        :return: The insert_placement of this DocxInsertImageRequest.  # noqa: E501
        :rtype: str
        """
        return self._insert_placement

    @insert_placement.setter
    def insert_placement(self, insert_placement):
        """Sets the insert_placement of this DocxInsertImageRequest.

        Optional; default is DocumentEnd.  Placement Type of the insert; possible values are: DocumentStart (very beginning of the document), DocumentEnd (very end of the document), BeforeExistingObject (right before an existing object - fill in the InsertPath field using the Path value from an existing object), AfterExistingObject (right after an existing object - fill in the InsertPath field using the Path value from an existing object)  # noqa: E501

        :param insert_placement: The insert_placement of this DocxInsertImageRequest.  # noqa: E501
        :type: str
        """

        self._insert_placement = insert_placement

    @property
    def insert_path(self):
        """Gets the insert_path of this DocxInsertImageRequest.  # noqa: E501

        Optional; location within the document to insert the object; fill in the InsertPath field using the Path value from an existing object.  Used with InsertPlacement of BeforeExistingObject or AfterExistingObject  # noqa: E501

        :return: The insert_path of this DocxInsertImageRequest.  # noqa: E501
        :rtype: str
        """
        return self._insert_path

    @insert_path.setter
    def insert_path(self, insert_path):
        """Sets the insert_path of this DocxInsertImageRequest.

        Optional; location within the document to insert the object; fill in the InsertPath field using the Path value from an existing object.  Used with InsertPlacement of BeforeExistingObject or AfterExistingObject  # noqa: E501

        :param insert_path: The insert_path of this DocxInsertImageRequest.  # noqa: E501
        :type: str
        """

        self._insert_path = insert_path

    @property
    def width_in_em_us(self):
        """Gets the width_in_em_us of this DocxInsertImageRequest.  # noqa: E501

        Optional: The width of the image in EMUs  # noqa: E501

        :return: The width_in_em_us of this DocxInsertImageRequest.  # noqa: E501
        :rtype: int
        """
        return self._width_in_em_us

    @width_in_em_us.setter
    def width_in_em_us(self, width_in_em_us):
        """Sets the width_in_em_us of this DocxInsertImageRequest.

        Optional: The width of the image in EMUs  # noqa: E501

        :param width_in_em_us: The width_in_em_us of this DocxInsertImageRequest.  # noqa: E501
        :type: int
        """

        self._width_in_em_us = width_in_em_us

    @property
    def height_in_em_us(self):
        """Gets the height_in_em_us of this DocxInsertImageRequest.  # noqa: E501

        Optional: The height of the image in EMUs  # noqa: E501

        :return: The height_in_em_us of this DocxInsertImageRequest.  # noqa: E501
        :rtype: int
        """
        return self._height_in_em_us

    @height_in_em_us.setter
    def height_in_em_us(self, height_in_em_us):
        """Sets the height_in_em_us of this DocxInsertImageRequest.

        Optional: The height of the image in EMUs  # noqa: E501

        :param height_in_em_us: The height_in_em_us of this DocxInsertImageRequest.  # noqa: E501
        :type: int
        """

        self._height_in_em_us = height_in_em_us

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocxInsertImageRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocxInsertImageRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    convertapi

    Convert API lets you effortlessly convert file formats and types.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class EnableSharedWorkbookResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'successful': 'bool',
        'edited_document_url': 'str'
    }

    attribute_map = {
        'successful': 'Successful',
        'edited_document_url': 'EditedDocumentURL'
    }

    def __init__(self, successful=None, edited_document_url=None):  # noqa: E501
        """EnableSharedWorkbookResponse - a model defined in Swagger"""  # noqa: E501

        self._successful = None
        self._edited_document_url = None
        self.discriminator = None

        if successful is not None:
            self.successful = successful
        if edited_document_url is not None:
            self.edited_document_url = edited_document_url

    @property
    def successful(self):
        """Gets the successful of this EnableSharedWorkbookResponse.  # noqa: E501

        True if successful, false otherwise  # noqa: E501

        :return: The successful of this EnableSharedWorkbookResponse.  # noqa: E501
        :rtype: bool
        """
        return self._successful

    @successful.setter
    def successful(self, successful):
        """Sets the successful of this EnableSharedWorkbookResponse.

        True if successful, false otherwise  # noqa: E501

        :param successful: The successful of this EnableSharedWorkbookResponse.  # noqa: E501
        :type: bool
        """

        self._successful = successful

    @property
    def edited_document_url(self):
        """Gets the edited_document_url of this EnableSharedWorkbookResponse.  # noqa: E501

        URL to the edited XLSX file; file is stored in an in-memory cache and will be deleted.  Call Finish-Editing to get the result document contents.  # noqa: E501

        :return: The edited_document_url of this EnableSharedWorkbookResponse.  # noqa: E501
        :rtype: str
        """
        return self._edited_document_url

    @edited_document_url.setter
    def edited_document_url(self, edited_document_url):
        """Sets the edited_document_url of this EnableSharedWorkbookResponse.

        URL to the edited XLSX file; file is stored in an in-memory cache and will be deleted.  Call Finish-Editing to get the result document contents.  # noqa: E501

        :param edited_document_url: The edited_document_url of this EnableSharedWorkbookResponse.  # noqa: E501
        :type: str
        """

        self._edited_document_url = edited_document_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EnableSharedWorkbookResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EnableSharedWorkbookResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
